@@ -18,10 +18,10 @@
 
 #' secretbase: Cryptographic Hash and Extendable-Output Functions
 #'
-#' SHA-3 cryptographic hash and SHAKE256 extendable-output functions (XOF). Fast
-#'     and memory-efficient implementation using the core algorithm from 'Mbed
-#'     TLS' under the Trusted Firmware Project
-#'     <https://www.trustedfirmware.org/projects/mbed-tls/>. The SHA-3
+#' SHA-256, SHA-3 cryptographic hash and SHAKE256 extendable-output functions
+#'     (XOF). Fast and memory-efficient implementation using the core algorithms
+#'     from 'Mbed TLS' under the Trusted Firmware Project
+#'     \url{https://www.trustedfirmware.org/projects/mbed-tls/}.\cr\cr The SHA-3
 #'     cryptographic hash functions are SHA3-224, SHA3-256, SHA3-384 and
 #'     SHA3-512, each an instance of the Keccak algorithm. SHAKE256 is one of
 #'     the two XOFs of the SHA-3 family, along with SHAKE128 (not implemented).
@@ -29,6 +29,9 @@
 #' @references The SHA-3 Secure Hash Standard was published by the National
 #'     Institute of Standards and Technology (NIST) in 2015 at
 #'     \doi{doi:10.6028/NIST.FIPS.202}.
+#'     
+#'     The SHA-256 Secure Hash Standard was published by NIST in 2002 at
+#'     \url{https://csrc.nist.gov/publications/fips/fips180-2/fips180-2.pdf}.
 #'
 #' @encoding UTF-8
 #' @author Charlie Gao \email{charlie.gao@@shikokuchuo.net}
@@ -40,7 +43,7 @@
 
 # secretbase - Main Functions --------------------------------------------------
 
-#' Cryptographic Hashing Using the SHA-3 Algorithm
+#' Cryptographic Hashing Using the SHA-3 Algorithms
 #'
 #' Returns a SHA-3 hash of the supplied R object or file.
 #'
@@ -57,6 +60,8 @@
 #' @param convert [default TRUE] if TRUE, the hash is converted to its hex
 #'     representation as a character string, if FALSE, output directly as a raw
 #'     vector, or if NA, a vector of (32-bit) integer values.
+#' @param file character file name / path. If specified, 'x' is ignored. The
+#'     file is hashed in a streaming fashion and may be larger than memory.
 #'
 #' @return A character string, raw or integer vector depending on 'convert'.
 #'
@@ -83,22 +88,39 @@
 #' # SHAKE256 hash to integer:
 #' sha3("secret base", bits = 32L, convert = NA)
 #'
-#' @export
-#'
-sha3 <- function(x, bits = 256L, convert = TRUE)
-  .Call(secretbase_sha3, x, bits, convert)
-
-#' @param file character file name / path. The file is hashed in a streaming
-#'     fashion and does not need to fit in memory.
-#' 
-#' @examples
 #' # SHA3-256 hash a file:
 #' file <- tempfile(); cat("secret base", file = file)
-#' sha3file(file)
+#' sha3(file = file)
 #' unlink(file)
-#'     
-#' @rdname sha3
+#'
 #' @export
 #'
-sha3file <- function(file, bits = 256L, convert = TRUE)
-  .Call(secretbase_sha3_file, file, bits, convert)
+sha3 <- function(x, bits = 256L, convert = TRUE, file)
+  if (missing(file)) .Call(secretbase_sha3, x, bits, convert) else
+    .Call(secretbase_sha3_file, file, bits, convert)
+
+#' Cryptographic Hashing Using the SHA-256 Algorithm
+#'
+#' Returns a SHA-256 hash of the supplied R object or file.
+#'
+#' @inheritParams sha3
+#'
+#' @return A character string, raw or integer vector depending on 'convert'.
+#'
+#' @examples
+#' # SHA-256 hash as character string:
+#' sha256("secret base")
+#'
+#' # SHA-256 hash as raw vector:
+#' sha256("secret base", convert = FALSE)
+#' 
+#' # SHA-256 hash a file:
+#' file <- tempfile(); cat("secret base", file = file)
+#' sha256(file = file)
+#' unlink(file)
+#'
+#' @export
+#'
+sha256 <- function(x, convert = TRUE, file)
+  if (missing(file)) .Call(secretbase_sha256, x, convert) else
+    .Call(secretbase_sha256_file, file, convert)
